@@ -39,7 +39,8 @@ __END__
 
 =head1 NAME
 
-Game::NURBS - Perl extension for manipulating NURBS curves 
+Game::NURBS - Perl extension for manipulating NURBS curves. There might
+also be some display code. 
 
 =head1 SYNOPSIS
 
@@ -47,6 +48,9 @@ Game::NURBS - Perl extension for manipulating NURBS curves
 
 =head1 DESCRIPTION
 
+Almost everything is based on the NURBS book (Springer) and is meant to
+generate 3D models.
+
 =head2 EXPORT
 
 =head1 SEE ALSO
